==> fastyle_dart-0.24.1.tar.gz: lib/ui/themes/dark/dark_themes.dart <==
import 'package:fastyle_dart/fastyle_dart.dart';
import 'package:flutter/cupertino.dart';

final kDarkBlueFastTheme = FastThemeFactory.buildDarkThemeWithColors(
  primaryColor: kFastDarkBlueColor,
  primaryColorDark: CupertinoColors.systemBlue.darkHighContrastColor,
  secondaryColor: kFastDarkTealColor,
  tertiaryColor: kFastDarkIndigoColor,
);

final kDarkIndigoFastTheme = FastThemeFactory.buildDarkThemeWithColors(
  primaryColor: kFastDarkIndigoColor,
  primaryColorDark: CupertinoColors.systemIndigo.darkHighContrastColor,
  secondaryColor: kFastDarkPurpleColor,
  tertiaryColor: kFastDarkTealColor,
);

final kDarkPinkFastTheme = FastThemeFactory.buildDarkThemeWithColors(
  primaryColor: kFastDarkPinkColor,
  primaryColorDark: CupertinoColors.systemPink.darkHighContrastColor,
  secondaryColor: kFastDarkPurpleColor,
  tertiaryColor: kFastDarkTealColor,
);

final kDarkPurpleFastTheme = FastThemeFactory.buildDarkThemeWithColors(
  primaryColor: kFastDarkPurpleColor,
  primaryColorDark: CupertinoColors.systemPurple.darkHighContrastColor,
  secondaryColor: kFastDarkIndigoColor,
  tertiaryColor: kFastDarkTealColor,
);

final kDarkTealFastTheme = FastThemeFactory.buildDarkThemeWithColors(
  primaryColor: kFastDarkTealColor,
  primaryColorDark: CupertinoColors.systemTeal.darkHighContrastColor,
  secondaryColor: kFastDarkPurpleColor,
  tertiaryColor: kFastDarkBlueColor,
);

final kDarkYellowFastTheme = FastThemeFactory.buildDarkThemeWithColors(
  primaryColor: kFastDarkYellowColor,
  primaryColorDark: CupertinoColors.systemYellow.darkHighContrastColor,
  secondaryColor: kFastDarkIndigoColor,
  tertiaryColor: kFastDarkTealColor,
);

final kDarkOrangeFastTheme = FastThemeFactory.buildDarkThemeWithColors(
  primaryColor: kFastDarkOrangeColor,
  primaryColorDark: CupertinoColors.systemOrange.darkHighContrastColor,
  secondaryColor: kFastDarkIndigoColor,
  tertiaryColor: kFastDarkTealColor,
);

==> fastyle_dart-0.33.0.tar.gz: lib/ui/themes/dark/dark_themes.dart <==
import 'package:fastyle_dart/fastyle_dart.dart';

final kDarkBlueFastTheme = FastThemeFactory.buildDarkThemeWithColors(
  primaryColor: kFastDarkBlueColor,
  primaryColorDark: kFastDarkBluePaletteColors.dark,
  secondaryColor: kFastDarkTealColor,
  tertiaryColor: kFastDarkIndigoColor,
);

final kDarkIndigoFastTheme = FastThemeFactory.buildDarkThemeWithColors(
  primaryColor: kFastDarkIndigoColor,
  primaryColorDark: kFastDarkIndigoPaletteColors.dark,
  secondaryColor: kFastDarkPurpleColor,
  tertiaryColor: kFastDarkTealColor,
);

final kDarkPinkFastTheme = FastThemeFactory.buildDarkThemeWithColors(
  primaryColor: kFastDarkPinkColor,
  primaryColorDark: kFastDarkPinkPaletteColors.dark,
  secondaryColor: kFastDarkPurpleColor,
  tertiaryColor: kFastDarkTealColor,
);

final kDarkPurpleFastTheme = FastThemeFactory.buildDarkThemeWithColors(
  primaryColor: kFastDarkPurpleColor,
  primaryColorDark: kFastDarkPurplePaletteColors.dark,
  secondaryColor: kFastDarkIndigoColor,
  tertiaryColor: kFastDarkTealColor,
);

final kDarkTealFastTheme = FastThemeFactory.buildDarkThemeWithColors(
  primaryColor: kFastDarkTealColor,
  primaryColorDark: kFastDarkTealPaletteColors.dark,
  secondaryColor: kFastDarkPurpleColor,
  tertiaryColor: kFastDarkBlueColor,
);

final kDarkYellowFastTheme = FastThemeFactory.buildDarkThemeWithColors(
  primaryColor: kFastDarkYellowColor,
  primaryColorDark: kFastDarkYellowPaletteColors.dark,
  secondaryColor: kFastDarkIndigoColor,
  tertiaryColor: kFastDarkTealColor,
);

final kDarkOrangeFastTheme = FastThemeFactory.buildDarkThemeWithColors(
  primaryColor: kFastDarkOrangeColor,
  primaryColorDark: kFastDarkOrangePaletteColors.dark,
  secondaryColor: kFastDarkIndigoColor,
  tertiaryColor: kFastDarkTealColor,
);
